Resp<T> class

Implementers
Available extensions

Constructors

Resp({String? message, String? title, String? uuid, T? data, int? code})
Resp.fromJson(Map<String, dynamic> json)

Properties

code ↔ int?
getter/setter pair
data ↔ T?
getter/setter pair
errno ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair
uuid ↔ String?
getter/setter pair

Methods

dataFromJson(Map<String, dynamic> json) → T?
isDataVali() → bool

Available on Resp, provided by the RespExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showErr(BuildContext context) → String?

Available on Resp, provided by the RespExt extension

superFromJson(Map<String, dynamic> json) → void

Available on Resp, provided by the RespExt extension

toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
valid() → bool

Available on Resp, provided by the RespExt extension

validNotGoLogin() → bool

Available on Resp, provided by the RespExt extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited