NetworkServiceResponse<T> class

Constructors

NetworkServiceResponse({T? content, bool? success, String? message})

Properties

content ↔ T?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited