UserTokenInfo class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkLogin() → void
clearLogin() Future
doLoad(SharedPreferences sp) → void
doSave(SharedPreferences sp) → void
getToken() String?
load() Future<UserTokenInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notLogin() bool
save() Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance UserTokenInfo
no setter

Constants

SP_AC_TOKEN → const String
SPKeyPrefix → const String