onError method
Called when an exception was occurred during the request.
Implementation
@override
Future onError(dio.DioException err, dio.ErrorInterceptorHandler handler) {
super.onError(err, handler);
return Future.value(true);
}
Called when an exception was occurred during the request.
@override
Future onError(dio.DioException err, dio.ErrorInterceptorHandler handler) {
super.onError(err, handler);
return Future.value(true);
}